==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-da-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Danish (http://www.transifex.com/tine20/tine20/language/da/)\nLanguage: da\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Navn"

, "Size"
: "Størrelse"

, "Last Modified"
: "Sidst redigeret"

, "Description"
: "Beskrivelse"

, "Folder, Folders"
: [
  "Mappe"
 ,"Mapper"

]
, "File, Files"
: [
  "Fil"
 ,"Filer"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "sti"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Oprettet af"

, "Creation Time"
: "Oprettelses tid"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Sidst redigeret den"

, "Last Modified By"
: "Sidst redigeret af"

, "Revision"
: "Revision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Upload fejlede"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Tags"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Upload"

, "Open Data Safe"
: ""

, "Folder Up"
: "Op"

, "Close Data Safe"
: ""

, "Filemanager"
: "Filmanager"

, "Save locally"
: "gem lokalt"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Type"

, "Not yet indexed"
: ""

, "Modified By"
: "Redigeret af"

, "Enter description"
: "Indtast beskrivelse"

, "Service Unavailable"
: "Service ikke tilgængelig"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Filmanageren er ikke konfigureret korrekt. Se {0}Tine 2.0 Admin FAQ{1} for konfiguration eller kontakt din administrator"

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vil du overskrive de følgende filer?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "emne med dette navn eksistere allerede!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopiere data .. {0}"

, "Moving data .. {0}"
: "Flytter data .. {0}"

, "Please wait"
: "Vent venligst"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: ""

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Opret mappe"

, "New Folder"
: "Ny mappe"

, "Please enter the name of the new folder:"
: "Indtast navnet på den nye mappe:"

, "No {0} added"
: "Ingen {0} tilføjet"

, "You have to supply a {0} name!"
: "Du skal skrive et {0} navn!"

, "Edit Properties"
: "Rediger egenskaber"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Indtast det nye navn for {0}:"

, "Not renamed {0}"
: "Ikke omdøbt {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Slet"

, "Do you really want to delete the following files?"
: "Vil du virkeligt slette de følgende filer?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mine mapper"

, "Shared folders"
: "Delte mapper"

, "Other users folders"
: "Andre brugeres mapper"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "administrer delte mapper"

, "Create new shared folders"
: "Opret ny delt mappe"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""





, "Folder"
: "Mappe"

, "File"
: "Fil"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Filemanager/js/Filemanager-lang-da-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Danish (http://www.transifex.com/tine20/tine20/language/da/)\nLanguage: da\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Usage"
: ""

, "Size"
: "Størrelse"

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "Revision Size"
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Service Unavailable"
: "Service ikke tilgængelig"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Filmanageren er ikke konfigureret korrekt. Se {0}Tine 2.0 Admin FAQ{1} for konfiguration eller kontakt din administrator"

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vil du overskrive de følgende filer?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "emne med dette navn eksistere allerede!"

, "Filemanager"
: "Filmanager"

, "Save locally"
: "gem lokalt"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Node Download Links"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "URL"
: ""

, "Created By"
: "Oprettet af"

, "Creation Time"
: "Oprettelses tid"

, "Expiration Time"
: ""

, "Password"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Sidst redigeret den"

, "Last Modified By"
: "Sidst redigeret af"

, "Folder"
: "Mappe"

, "Total size of all available revisions"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Upload"

, "Open Data Safe"
: ""

, "Folder Up"
: "Op"

, "Locking data safe..."
: ""

, "Unlocking data safe..."
: ""

, "Close Data Safe"
: ""

, "Upload Failed"
: "Upload fejlede"

, "It is not permitted to store files in this folder!"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "path"
: "sti"

, "Reload"
: ""

, "Create Folder"
: "Opret mappe"

, "New Folder"
: "Ny mappe"

, "Please enter the name of the new folder:"
: "Indtast navnet på den nye mappe:"

, "No {0} added"
: "Ingen {0} tilføjet"

, "You have to supply a {0} name!"
: "Du skal skrive et {0} navn!"

, "Edit Properties"
: "Rediger egenskaber"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Indtast det nye navn for {0}:"

, "Not renamed {0}"
: "Ikke omdøbt {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Slet"

, "Do you really want to delete the following files?"
: "Vil du virkeligt slette de følgende filer?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Name"
: "Navn"

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Revision"
: "Revision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopiere data .. {0}"

, "Moving data .. {0}"
: "Flytter data .. {0}"

, "Confirm Changing of Folder Grants"
: ""

, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
: ""

, "Please wait"
: "Vent venligst"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "File"
: "Fil"

, "Public Links"
: ""

, "Type"
: "Type"

, "Indexed"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Redigeret af"

, "Last Modified"
: "Sidst redigeret"

, "Description"
: "Beskrivelse"

, "Enter description"
: "Indtast beskrivelse"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "This file has no contents. The Upload has failed or has not yet finished."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Content type"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mine mapper"

, "Shared folders"
: "Delte mapper"

, "Other users folders"
: "Andre brugeres mapper"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "manage shared folders"
: "administrer delte mapper"

, "Create new shared folders"
: "Opret ny delt mappe"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""






, "Once a Day"
: ""

, "Download Link"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
